@@ -46,10 +46,10 @@
 #' @param network.segment.wt thickness of network segments (default is 3)
 #' @param network.thresh Network structure is summarized in the animation in a binary way, regardless of whether or not the \code{network} is continuously weighted or not. The value of \code{network.thresh} determines the level below which no connection is shown, and above which an active connection is shown via colored rings and connecting segments.
 #' @param network.times Numeric vector. If network time grid doesn't match \code{n.frames}, supply the times at which the network has been evaluated so it can be interpolated using smoothing splines.
-#' @param override Logical variable toggling where or not to override warnings about how long the animation procedure will take.
+#' @param override Logical variable toggling where or not to override warnings about how long the animation procedure will take and whether to check for the presence of previous HTML animations before overwritting.
 #' @param par.opts Options passed to \code{par()} before creating each frame.
 #' @param paths.proj PROJ.4 string corresponding to the projection of the data. Default is "+proj=longlat".
-#' @param paths.tranform.crs a PROJ.4 string of coordinate projection transformation based on the animals' location; default is "+proj=aea +lat_1=30 +lat_2=70".
+#' @param paths.tranform.crs a PROJ.4 string of coordinate projection transformation based on the animals' location; default is \code{"+proj=aea +lat_1=30 +lat_2=70"}.
 #' @param plot.date Logical variable toggling date text at the time center of the animation.
 #' @param pt.alpha alpha value for the points
 #' @param pt.cex A numeric value giving the character expansion (size) of the points for each individual. Default is 1.
@@ -68,7 +68,9 @@
 #' @param times If all paths are already synchronous, another option for passing the data is to define \code{paths} as a list of matrices, all with the same number of rows, and to specify the times separately via this argument.
 #' @param uncertainty.level value in (0, 1) corresponding to \code{level} at which to draw uncertainty ellipses. \code{NA} (default) results in no ellipses.
 #' @param uncertainty.type State what type of uncertainty plot 1 is default for tails more than 1 is amount of predicted trajectories for each unique individual and blurs for blur plot
-#' @param whole.path logical. If \code{TRUE} (default = \code{FALSE}), the complete interpolated trajectories will be plotted in the background of the animation. If \code{whole.path = TRUE}, consider also setting \code{tail.length = 0}.
+#' @param whole.path logical. If \code{TRUE} (default = \code{FALSE}), the complete interpolated trajectories will be plotted in the background of the animation matching \code{pt.colors}.
+#' @param whole.path.wd line weight (lwd) for whole paths
+#' @param whole.path.alpha transparency level (0 to 1) for whole paths
 #' @param verbose logical; \code{TRUE} prints messages about fitting details
 #' @param xlim Boundaries for plotting. If left undefined, the range of the data will be used.
 #' @param ylim Boundaries for plotting. If left undefined, the range of the data will be used.
@@ -150,10 +152,11 @@ animate_paths <- function(paths, coord = c("x", "y"), Time.name = "time",
                           simulation = FALSE, simulation.iter = 12, tail.alpha = 0.6, 
                           tail.colors = "gray87", tail.length = 5, tail.wd = 1, 
                           theme_map = NULL, times = NULL, uncertainty.level = NA, uncertainty.type = 1, 
-                          whole.path = FALSE, xlim = NULL, ylim = NULL, verbose = FALSE, ...) {
+                          whole.path = FALSE, whole.path.wd = 1, whole.path.alpha = 1,
+                          xlim = NULL, ylim = NULL, verbose = FALSE, ...) {
   
   ## permission to overwrite. If not granted, suggestions given to save animations
-  check <- check_overwrite(method=method, return.paths=return.paths, ...)
+  check <- check_overwrite(method=method, return.paths=return.paths, override = override, ...)
   if(isFALSE(check)){
     return(
       message(paste(
@@ -450,6 +453,7 @@ animate_paths <- function(paths, coord = c("x", "y"), Time.name = "time",
   ## adjust center + scale for google map ----
   if(interpolation_type == "gam"){
     if(inherits(bg[[1]], "ggmap")){
+      
       for(i in 1:length(paths.interp)){
         for(rep in 1:dim(paths.interp[[i]])[2]){
           paths.i.rep.df <- as.data.frame(paths.interp[[i]][, rep, c('mu.x', 'mu.y')])
@@ -499,7 +503,8 @@ animate_paths <- function(paths, coord = c("x", "y"), Time.name = "time",
     simulation = simulation, simulation.iter = simulation.iter, tail.alpha = tail.alpha, 
     tail.colors = tail.colors, tail.length = tail.length, tail.wd = tail.wd, theme_map = theme_map, 
     time.grid = time.grid, Time.name = Time.name, uncertainty.level = uncertainty.level, 
-    uncertainty.type = uncertainty.type, whole.path = whole.path, xlim = xlim, ylim = ylim, ...
+    uncertainty.type = uncertainty.type, whole.path = whole.path, whole.path.wd = whole.path.wd, 
+    whole.path.alpha = whole.path.alpha, xlim = xlim, ylim = ylim, ...
   )
   
   message(paste("Total time", round(as.numeric(Sys.time()) - as.numeric(start.time), 2), "seconds."))
