@@ -60,6 +60,8 @@
 #' @param uncertainty.level value in (0, 1) corresponding to \code{level} at which to draw uncertainty ellipses. \code{NA} (default) results in no ellipses.
 #' @param uncertainty.type State what type of uncertainty plot 1 is default for tails more than 1 is amount of predicted trajectories for each unique individual and blurs for blur plot
 #' @param whole.path logical. If \code{TRUE} (default = \code{FALSE}), the complete interpolated trajectories will be plotted in the background of the animation. If \code{whole.path = TRUE}, consider also setting \code{tail.length = 0}.
+#' @param whole.path.wd line weight (lwd) for whole paths
+#' @param whole.path.alpha transparency level (0 to 1) for whole paths
 #' @param xlim Boundaries for plotting. If left undefined, the range of the data will be used.
 #' @param ylim Boundaries for plotting. If left undefined, the range of the data will be used.
 #' @param ... other arguments to be passed to \code{ani.options} to animation options such as the time interval between image frames.
@@ -86,7 +88,7 @@ animation_expression <- function(bg, bg.axes, bg.misc, bg.opts, blur.size, cliqu
                                  pt.cex, pt.colors, pt.wd, res, scale, simulation, simulation.iter, 
                                  tail.alpha, tail.colors, tail.length, tail.wd, theme_map, 
                                  time.grid, Time.name, uncertainty.level, uncertainty.type, 
-                                 whole.path, xlim, ylim, ...) {
+                                 whole.path, whole.path.wd, whole.path.alpha, xlim, ylim, ...) {
   
   # set option for animation frame and start time
   ani.options(interval = interval, ani.width = res * 480, ani.height = res * 480, verbose = F)
@@ -145,8 +147,10 @@ animation_expression <- function(bg, bg.axes, bg.misc, bg.opts, blur.size, cliqu
         ## whole path ----
         if (isTRUE(whole.path)) {
           for (id in 1:length(paths)) {
-            lines(x = paths.interp[[id]][ , , c("mu.x", "mu.y")], 
-                  col = id)
+            lines(x = paths.interp[[id]][ , , c("mu.x", "mu.y")],
+                  lwd = whole.path.wd,
+                  col = adjustcolor(pt.colors[id, 1 + id %in% dimmed],
+                                    alpha.f = whole.path.alpha))
           }
         }
         ## add blur ellipse ----
@@ -156,7 +160,8 @@ animation_expression <- function(bg, bg.axes, bg.misc, bg.opts, blur.size, cliqu
             points(blur_point(x=matrix(c(1.96*paths.interp[[id]][frame, ,"se.mu.x"],0,0,
                                          1.96*paths.interp[[id]][frame, ,"se.mu.y"]), 2,2),
                               center = c(paths.interp[[id]][frame, ,"mu.x"], paths.interp[[id]][frame, ,"mu.y"]),
-                              col = tail.colors, alpha_mult = new_alpha(paths.interp[[id]][frame, ,"se.mu.x"],paths.interp[[id]][frame, ,"se.mu.y"])))
+                              col = tail.colors, alpha_mult = new_alpha(paths.interp[[id]][frame, ,"se.mu.x"],
+                                                                        paths.interp[[id]][frame, ,"se.mu.y"])))
           }
         } else if(uncertainty.type > 1){
           ## multiple trajectories ----
@@ -386,7 +391,10 @@ animation_expression <- function(bg, bg.axes, bg.misc, bg.opts, blur.size, cliqu
         ## whole path ----
         if (isTRUE(whole.path)) {
           for (id in 1:length(paths)) {
-            lines(x = paths.interp[[id]][ , , c("mu.x", "mu.y")])
+            lines(x = paths.interp[[id]][ , , c("mu.x", "mu.y")],
+                  lwd = whole.path.wd,
+                  col = adjustcolor(pt.colors[id, 1 + id %in% dimmed],
+                                    alpha.f = whole.path.alpha))
           }
         }
         if(uncertainty.type == "blur"){
@@ -400,7 +408,8 @@ animation_expression <- function(bg, bg.axes, bg.misc, bg.opts, blur.size, cliqu
             points(blur_point(x=matrix(c(1.96*paths.interp[[id]][frame, ,"se.mu.x"],0,0,
                                          1.96*paths.interp[[id]][frame, ,"se.mu.y"]), 2,2),
                               center = c(paths.interp[[id]][frame, ,"mu.x"], paths.interp[[id]][frame, ,"mu.y"]),
-                              col = tail.colors, alpha_mult = new_alpha(paths.interp[[id]][frame, ,"se.mu.x"],paths.interp[[id]][frame, ,"se.mu.y"])))
+                              col = tail.colors, alpha_mult = new_alpha(paths.interp[[id]][frame, ,"se.mu.x"],
+                                                                        paths.interp[[id]][frame, ,"se.mu.y"])))
           }
         } else if(uncertainty.type > 1){
           ## multiple trajectories ----
