@@ -2,12 +2,14 @@
 #'
 #' @param method passed from animate_paths()
 #' @param return.paths passed from animate_paths()
+#' @param override if \code{TRUE}, no check performed and background files are overwritten
 #' @param ... passed from animate_paths(); used to check for user-specified value for img.name
 #'
 #' @return NULL, unless there is risk of over-writting and the user interrupts animation (\code{FALSE})
 #'
-check_overwrite <- function(method, return.paths, ...){
+check_overwrite <- function(method, return.paths, override = FALSE, ...){
   
+  if(isTRUE(override)) return()
   #to detect if img.name argument was used
   logical_imgname <- function(...){
     args <- list(...)
@@ -28,7 +30,7 @@ check_overwrite <- function(method, return.paths, ...){
   }
   #message asking for user's permission to overwrite
   else if(folders_T_or_F == T & imgname_T_or_F == F & method == "html"){
-    remove_img_resp = readline(prompt= "Would you like anipaths to write over existing files? Y/N \n")
+    remove_img_resp = readline(prompt= "Would you like anipaths to write over existing files (Y/N)? ")
     remove_img_resp <- gsub(" ", "", toupper(remove_img_resp))
     #user wants to overwrite existing files. Files are deleted and recreated to only store current animation
     if(remove_img_resp == 'Y' || remove_img_resp == 'YES'){
